raytraverse.lightfield
==========================================================

LightField
---------------------------------

.. autoclass:: raytraverse.lightfield.LightField
    :members:
    :undoc-members:
    :show-inheritance:


LightPlaneKD
---------------------------------

.. autoclass:: raytraverse.lightfield.LightPlaneKD
    :members:
    :undoc-members:
    :show-inheritance:

SunsPlaneKD
---------------------------------

.. autoclass:: raytraverse.lightfield.SunsPlaneKD
    :members:
    :undoc-members:
    :show-inheritance:

SensorPlaneKD
---------------------------------

.. autoclass:: raytraverse.lightfield.SensorPlaneKD
    :members:
    :undoc-members:
    :show-inheritance:

SunSensorPlaneKD
---------------------------------

.. autoclass:: raytraverse.lightfield.SunSensorPlaneKD
    :members:
    :undoc-members:
    :show-inheritance:


LightResult
---------------------------------

.. autoclass:: raytraverse.lightfield.LightResult
    :members:
    :undoc-members:
    :show-inheritance:

ZonalLightResult
---------------------------------

.. autoclass:: raytraverse.lightfield.ZonalLightResult
    :members:
    :undoc-members:
    :show-inheritance:

sets
----

LightSet
~~~~~~~~

.. autoclass:: raytraverse.lightfield.sets.LightSet
    :members:
    :undoc-members:
    :show-inheritance:

LightPointSet
~~~~~~~~~~~~~

.. autoclass:: raytraverse.lightfield.sets.LightPointSet
    :members:
    :undoc-members:
    :show-inheritance:

MultiLightPointSet
~~~~~~~~~~~~~~~~~~

.. autoclass:: raytraverse.lightfield.sets.MultiLightPointSet
    :members:
    :undoc-members:
    :show-inheritance:

SensorPointSet
~~~~~~~~~~~~~~

.. autoclass:: raytraverse.lightfield.sets.SensorPointSet
    :members:
    :undoc-members:
    :show-inheritance:

RaggedResult
------------

.. autoclass:: raytraverse.lightfield.RaggedResult
    :members:
    :undoc-members:
    :show-inheritance:

ResultAxis
------------

.. autoclass:: raytraverse.lightfield.ResultAxis
    :members:
    :undoc-members:
    :show-inheritance:
